@@ -16,50 +16,62 @@
 
 ### Quantities related to the empirical copula #################################
 
-##' Empirical copula of U at u
+##' Empirical copula of X at x
 ##'
-##' @title Empirical copula of U at u
-##' @param u (m, d) matrix of evaluation points
-##' @param U (n, d) matrix of pseudo-data based on which the empirical copula
+##' @title Empirical CDF and hence copula of X at x
+##' @param x (m, d) matrix of evaluation points
+##' @param X (n, d) matrix of pseudo-data based on which the empirical copula
 ##'        is computed (if not pseudo-data already, use do.pobs=TRUE)
-##' @param offset scaling factor sum()/(n+offset) when computing the empirical
-##'        copula
+##' @param offset scaling factor of result which is  sum(....)/(n+offset)
 ##' @param method method string ("C" for C code; "R" for R code)
-##' @return empirical copula of U at u
-##' @author Ivan Kojadinovic and Marius Hofert
-##' Note: See the .Rd for a nice graphical check with the Kendall function
-C.n <- function(u, U, offset=0, method=c("C", "R"))
+##' @return empirical CDF / copula of X at x
+##' @author Ivan Kojadinovic, Marius Hofert and Martin (C.n -> F.n; re-organisation)
+##' Note: See ../man/empcop.Rd for a nice graphical check with the Kendall function
+F.n <- function(x, X, offset=0, method=c("C", "R"))
+## {
+##     if(!is.matrix(x)) x <- rbind(x, deparse.level=0L)
+##     if(!is.matrix(X)) X <- rbind(X, deparse.level=0L)
+##     structure(class = "mvFn", x=x, X=X, ## <- so the result can be plotted/printed ..
+##               .Fn(x, X, offset=offset, method=method))
+## }
+
+## .Fn <- function(x, X, offset=0, method=c("C", "R"))
 {
-    if(!is.matrix(u)) u <- rbind(u, deparse.level=0L)
-    if(!is.matrix(U)) U <- rbind(U, deparse.level=0L)
-    stopifnot((d <- ncol(U)) == ncol(u), 0 <= u, u <= 1)
+    stopifnot(is.numeric(d <- ncol(X)), is.matrix(x), d == ncol(x))
+    n <- nrow(X)
+    if(d == 1)
+	vapply(x, function(x.) sum(X <= x.), NA_real_) / (n+offset)
+    else { ## d > 1
+	method <- match.arg(method)
+	switch(method,
+	       "C"={
+		   m <- nrow(x)
+		   .C(Cn_C,		# see ../src/empcop.c
+		      as.double(X),
+		      as.integer(n),
+		      as.integer(d),
+		      as.double(x),
+		      as.integer(m),
+		      ec=double(m),
+		      as.double(offset))$ec
+	       },
+	       "R"={
+		   ## == apply(x, 1, function(x.) sum(colSums(t(X)<=x.)==d)/(n+offset) )
+		   ## but vapply is slightly faster (says MH)
+		   tX <- t(X)
+		   vapply(1:nrow(x), function(k) sum(colSums(tX <= x[k,]) == d), NA_real_) /
+		       (n + offset)
+	       },
+	       stop("wrong 'method': ", method))
+    }
+}
+
+C.n <- function(u, U, offset=0, method=c("C", "R")) {
     if(any(U < 0, 1 < U))
         stop("'U' must be in [0,1].. possibly use 'U=pobs(x)'...")
-    n <- nrow(U)
-
-    ## d = 1
-    if(d==1) return( vapply(u, function(u.) sum(U <= u.)/(n+offset), NA_real_) )
-
-    ## d > 1
-    method <- match.arg(method)
-    switch(method,
-           "C"={
-               m <- nrow(u)
-               .C(Cn_C, # see ../src/empcop.c
-                  as.double(U),
-                  as.integer(n),
-                  as.integer(d),
-                  as.double(u),
-                  as.integer(m),
-                  ec=double(m),
-                  as.double(offset))$ec
-           },
-           "R"={
-               ## alternatively, use apply(u, 1, function(u.) sum(colSums(t(U)<=u.)==d)/(n+offset) )
-               ## but vapply is slightly faster
-               vapply(1:nrow(u), function(k) sum( colSums(t(U)<=u[k,])==d ) / (n+offset), NA_real_)
-           },
-           stop("wrong method"))
+    if(any(u < 0, 1 < U))
+        stop("'u' must be in [0,1].")
+    F.n(u, U, offset=offset, method=method)
 }
 
 Cn <- function(x,w) {
@@ -76,11 +88,11 @@ Cn <- function(x,w) {
 ##'        is computed.
 ##' @param j.ind dimensions for which the partial derivatives should be estimated
 ##' @param b bandwidth in (0, 1/2) for the approximation
-##' @param ... additional arguments passed to Cn()
+##' @param ... additional arguments passed to F.n()
 ##' @return (m, length(j.ind))-matrix containing the estimated partial
 ##'         derivatives with index j.ind of the empirical copula of U at u
 ##' @author Marius Hofert
-##' Note: maybe provide a C version (as for Cn) with .Call
+##' Note: maybe provide a C version (as for F.n) with .Call
 dCn <- function(u, U, j.ind=1:d, b=1/sqrt(nrow(U)), ...)
 {
     ## check
@@ -109,14 +121,14 @@ dCn <- function(u, U, j.ind=1:d, b=1/sqrt(nrow(U)), ...)
         ## Build the two evaluation matrices for Cn (matrix similar to u with
         ## column j replaced). Note, this is slightly inefficient for those u < b
         ## but at least we can "matricize" the problem.
-        ## 1) compute C.n(u.up)
+        ## 1) compute F.n(u.up)
         u.up <- u
         u.up[,j] <- adj.u.up(u.up[,j])
-        Cn.up <- C.n(u.up, U=U, ...)
-        ## 2) compute C.n(u.low)
+        Cn.up <- F.n(u.up, U, ...)
+        ## 2) compute F.n(u.low)
         u.low <- u
         u.low[,j] <- adj.u.low(u.low[,j])
-        Cn.low <- C.n(u.low, U=U, ...)
+        Cn.low <- F.n(u.low, U, ...)
         ## 3) compute difference quotient
         (Cn.up - Cn.low) / (2*b)
     }, numeric(m))
@@ -141,11 +153,12 @@ dCn <- function(u, U, j.ind=1:d, b=1/sqrt(nrow(U)), ...)
 ##'         where we don't just compare U with u multiple times
 ##'       - well, actually, we only need this twice (and have to call C.n with
 ##'         adjusted arguments u d times anyways...)
+##' ### MM: not exported, nor documented, nor used *ANYWHERE* in copula pkg
 pobsInd <- function(u, U)
 {
-    stopifnot(length(du <- dim(u))==2,
-              length(dU <- dim(U))==2,
-              dU[2]==du[2])
-    vapply(1:du[1], function(k) t(U) <= u[k,],
-           matrix(logical(0), nrow=dU[2], ncol=dU[1]))
+    stopifnot(length(du <- dim(u)) == 2,
+	      length(dU <- dim(U)) == 2, dU[2] == du[2])
+    tU <- t(U) ## MM: even faster with tu <- t(u);  U <= tu[,k] .. needs more work
+    vapply(seq_len(du[1]), function(k) tU <= u[k,],
+	   array(logical(0), dU[2:1]))
 }
